#!/usr/bin/python

import os, string, time
from ActionLog import ActionLog


class SnmpResultCheckError (Exception):
	def __init__ (self, value):
		self.value = value
	
	def __str__ (self):
		return self.value


class NetSnmp:
	"Net-Snmp Tools library class"

	def __init__ (self, options, al):
		self.snmpOptions	= options
		self.al			= al
		self.__wheel		= 0


	def _SnmpGet (self, oid):
		if self.__wheel:
			self.al.Wheeling ()

		snmpget	= os.environ.get ("SNMPGET")
		cmd	= snmpget + " " + self.snmpOptions + " " + oid
		str	= self.al.Popen (cmd, "r")
		return str
		

	def _SnmpGetNext (self, oid):
		if self.__wheel:
			self.al.Wheeling ()

		snmpgetnext	= os.environ.get ("SNMPGETNEXT")
		cmd	= snmpgetnext + " " + self.snmpOptions + " " + oid
		str	= self.al.Popen (cmd, "r")
		return str
		

	def SetWheel (self, option = "on"):
		opt = str (option)
		if opt == "on" or opt == "On" or opt == "ON":
			self.__wheel = 1
		else:
			self.__wheel = 0
			

	def SnmpSet (self, express):
		if self.__wheel:
			self.al.Wheeling ()

		snmpset	= os.environ.get ("SNMPSET")
		cmd	= snmpset + " " + self.snmpOptions + " " + express
		str	= self.al.Popen (cmd, "r")
		return str
		

	def GetValue (self, str, type):
		if str is None:
			return None

		ret	= string.find (str, " = ")
		if ret == -1:
			return None

		return type (str[ret + 3:])


	def SnmpGet (self, oid, type):
		return self.GetValue (self._SnmpGet (oid), type)


	def SnmpGetNext (self, oid, type):
		return self.GetValue (self._SnmpGetNext (oid), type)


	def GetTableIndex (self, item):
		str	= self._SnmpGetNext (item)
		dot1	= string.rfind (item, ".")
		dot2	= string.rfind (str, ".")

		#if dot1 == -1 or dot2 == -1 or ((item != str[:dot2]) and (item[:dot1] != str[:dot2])):
		if dot1 != -1:
			item = item[:dot1]

		if dot2 == -1 or (string.find (str[:dot2], item) == -1):
			raise SnmpResultCheckError (item + " <-> " + str)

		if str is None:
			return None

		ret1	= string.find (str, " = ")
		if ret1 == -1:
			return None

		ret2	= string.rfind (str[0:ret1], ".")
		if ret2 == -1:
			return None

		return str[ret2 + 1:ret1]
