#!/usr/bin/python

import time, os, sys
from stat import *
from evlsnmp.NetSnmp import NetSnmp
from evlsnmp.POSIXEvent import *
from evlsnmp.ActionLog import ActionLog


def TestEventLog ():
	print "Event Log Test",
	sys.stdout.flush ()

	query = PEventQuery (snmp)
	ret_q = query.CreateEventQuery ("event_type=5555", "seek")

	os.system ("/sbin/evlsend -f LOCAL1 -t 5555 -m 'evlogSubagent: Event Log Test'")
	pEvlog = PEventLog (snmp)
	pEvlog.SetLogDefaultQuery (ret_q)
	pEvlog.GetAttributes ()
	# pEvlog.ShowAttributes ()
	pEvlog.SetLogDefaultQuery (0)
	query.DestroyEventQuery (ret_q)
	print ":PASSED"


def TestEventNotify ():
	# First we create and destroy a notify
	print "Event Notify Test",
	sys.stdout.flush ()
	query = PEventQuery (snmp)
	ret_q = query.CreateEventQuery ("(data contains \"First test!!!\")", "notify")

	notify = PEventNotify (snmp)
	ret_n = notify.CreateEventNotify (ret_q, "true", "false")

	notify.DestroyEventNotify (ret_n)
	query.DestroyEventQuery (ret_q)
	print ":PASSED"


def TestEventAction ():
	# Then we test the action
	tmpFile = "/tmp/evlogAction.log"
	os.system ("cp -f /dev/null " + tmpFile)

	print "Event Action Test",
	sys.stdout.flush ()
	query = PEventQuery (snmp)
	ret_q = query.CreateEventQuery ("(data contains \"evlogSubagent: Event Action Test\")", "seek")

	handler = PEventHandler (snmp)
	ret_h = handler.CreateEventHandler ("date > " + tmpFile, None)

	action = PEventAction (snmp)
	ret_a = action.CreateEventAction (ret_q, ret_h, "OnceOnly")

	# Generate such a event
	os.system ("/sbin/evlsend -f LOCAL1 -t 9876 -m 'evlogSubagent: Event Action Test'")

	# Wait some time to invoke the handler
	time.sleep (5)
	aStat = os.stat (tmpFile)
	mode = aStat[ST_MODE]
	if S_ISREG (mode):
		if aStat[ST_SIZE] > 0:
			os.system ("cp -f /dev/null " + tmpFile)
			# OnceOnly is used, so we needn't delete the action table
			#
			# Known Bug
			#
			action.DestroyEventAction (ret_a)
			handler.DestroyEventHandler (ret_h)
			query.DestroyEventQuery (ret_q)
			print ":PASSED"
			return 0

	# Destroy all created tables
	action.DestroyEventAction (ret_a)
	handler.DestroyEventHandler (ret_h)
	query.DestroyEventQuery (ret_q)
	# We have destroy the action table, so needn't destroy the query table again
	print ":FAILED"
	return -1


def TestEventConfig ():
	print "Event Config Test",
	sys.stdout.flush ()

	# First get the original config settings
	config = PEventConfig (snmp)
	config.GetConfig ()
	oldDups     = config.discardDups
        oldInterval = config.discardInterval
        oldDupCount = config.discardDupCount
        oldFilter   = config.screenFilter
        oldLookback = config.lookbackSize

	# Set new values diff with old ones
	if oldDups == 1:
		newDups = 2
	else:
		newDups = 1

	config.SetConfigDiscardDups (newDups)
	config.SetConfigDiscardInterval (oldInterval + 1)
	config.SetConfigDiscardDupCount (oldDupCount + 1)
	config.SetConfigLookbackSize (oldLookback + 1)

	if oldFilter == 0:
		query = PEventQuery (snmp)
		newFilter = query.CreateEventQuery ("(data contains \"Subagent: Event Config Test\")", "seek")
	else:
		newFilter = 0

	config.SetConfigScreenFilter (newFilter)

	# Set back to original settings
	config.SetConfigDiscardDups (oldDups)
	config.SetConfigDiscardInterval (oldInterval)
	config.SetConfigDiscardDupCount (oldDupCount)
	config.SetConfigScreenFilter (oldFilter)
	config.SetConfigLookbackSize (oldLookback)

	if newFilter != 0:
		query.DestroyEventQuery (newFilter)
	print ":PASSED"


def TestEventFacility ():
	print "Event Facility Test",
	sys.stdout.flush ()

	facility = PEventFacility (snmp)
	facility.GetFacility ()
	#facility.ShowFacility ()
	print ":PASSED"



############################
# Main program begins here #
############################

# Initailize the al and snmp
al = ActionLog (os.environ.get ("APILOG"))
al.SetNoticeLevel (1)
al.WriteLogHead ("Event log Remote Access Test Suite Log")
options=os.environ.get ("SNMP_OPTIONS")
snmp = NetSnmp (options, al)
snmp.SetWheel ("off")

#import os
#TestEventLog ()
#os.sys.exit(0)

# Run tests
try:
	TestEventLog ()
	pass
except:
	print ":FAILED"
try:
	TestEventNotify ()
	pass
except:
	print ":FAILED"
try:
	TestEventAction ()
	pass
except:
	print ":FAILED"
try:
	TestEventConfig ()
	pass
except:
	print ":FAILED"
try:
	TestEventFacility ()
	pass
except:
	print ":FAILED"
